program memtest

!   This tests memory by generating a large array using subroutine bcnrand,
!   regenerating the same sequence in a separate array, and then comparing the
!   two arrays.  This test can be repeated as often as desired.

!   The parameter m is the number of iterations of the test.  The parameter
!   maxerr is the number of errors after which execution is terminated.
!   The parameter n is the size of the two arrays, in 8-byte words.  The
!   default value of n below, namely 10,000,000, results in a program of size
!   approximately 160 Mbyte.

!   See comments below for complete details of using bcnrandx.
!   On certain systems with a fused multiply-add instruction, see !> comments.

!   David H Bailey    2008-08-25

!   Parameters:
!     m       Number of iterations of the test; default = 100.
!     maxerr  Number of errors after which run is terminated; default = 100.
!     n       Size of each of the two arrays, in 8-byte words; default =
!             10,000,000 (resulting in a program about 160 Mbytes long).

implicit none
integer i, j, kerr, m, maxerr, n
parameter (m = 100, maxerr = 100, n = 10000000)
real*8 a, aj, t1, t2, t3, x(n), y(n)
parameter (a = 3.d0**33 + 100.d0)
save

kerr = 0

do j = 1, m                                                                       
  write (6, *) 'start of trial ', j, m
  aj = (j-1)*m + a
  call bcnrand (n, aj, x)
  call bcnrand (n, aj, y)

  do i = 1, n
    if (x(i) /= y(i)) then
      write (6, '(i10,2z20,2i12)') i, x(i), y(i), loc(x(i)), loc(y(i))
      kerr = kerr + 1
      if (kerr == maxerr) stop
    endif
  enddo
enddo

stop
end
